@@ -1,7 +1,8 @@
-# coding=utf-8
+﻿# coding=utf-8
 import unittest
 from filmweb import Filmweb
 import Levenshtein
+from datetime import datetime
 
 
 class Serialparser(unittest.TestCase):
@@ -14,7 +15,7 @@ class Serialparser(unittest.TestCase):
         self.assertTrue( self.serial in found_movies )
 
     def test_year(self):
-        self.assertEqual( self.serial['year'], '1994 - 2004')
+        self.assertEqual( self.serial['year'], '1994-2004')
 
 
 
@@ -28,12 +29,6 @@ class CheckMovieInfos(unittest.TestCase):
         found_movies = self.fa.search_movie(u'Dziewczyna z sąsiedztwa')
         self.assertTrue( self.movie in found_movies )
 
-    def test_levenstein(self):
-        org_title = u'The Girl Next Door'.replace("The","")
-        self.assertEqual('Girl Next Door, The',self.movie['title_original'])
-        self.assertEqual( Levenshtein.distance(org_title,self.movie['title_original'].replace("The","")) , 3 )
-
-
 
 class MovieNextTest(unittest.TestCase):
     def setUp(self):
@@ -71,13 +66,13 @@ class Movieparser(unittest.TestCase):
 
         self.assertEqual( len(self.movie['basicinfo']), 5)
 
-        self.assertEqual( len(self.movie['photos']), 51 )
+        self.assertEqual( len(self.movie['photos']), 45 )
 
         self.assertEqual('Leon zawodowiec',self.movie.title,)
         #self.assertEqual('Léon',self.movie['title_original'],)
 
     def test_year(self):
-        self.assertEqual( self.movie['year'], 1994)
+        self.assertEqual( self.movie['year'], '1994')
 
 
 class Osobaparser(unittest.TestCase):
@@ -102,7 +97,8 @@ class Osobaparser(unittest.TestCase):
         self.assertGreater(self.osoba['filmography'],0)
 
         film = filmography[0]
-        self.assertEqual(film.objID,635169)
+        self.assertEqual(film.objID, 694864)
+
 
 class PosterEmptyTest(unittest.TestCase):
     def setUp(self):
@@ -142,3 +138,28 @@ class NadZycieTest(unittest.TestCase):
         p = self.movie['cast'][3]
         self.assertEqual(p['roleType'],u'aktor')
 
+    def test_posters(self):
+        self.assertEqual(len(self.movie['posters']), 2)
+
+
+class IxjanaTest(unittest.TestCase):
+    def setUp(self):
+        self.fa = Filmweb('http')
+        self.movie = self.fa.get_movie(598624)
+
+    def test_cast(self):
+        self.assertIsNotNone( self.movie['cast'] )
+        p = self.movie['cast'][5]
+        self.assertEqual(p['roleType'],u'aktor')
+
+
+class EpisodesTest(unittest.TestCase):
+    def setUp(self):
+        self.fa = Filmweb('http')
+        self.movie = self.fa.get_movie(130177) #Dr House
+    def test_episode(self):
+        episode = self.movie['episodes'][47]
+        self.assertEqual(episode['name'],u'Cane & Able')
+        self.assertEqual(episode['season'],3)
+        self.assertEqual(episode['number'],2)
+        self.assertEqual(episode['date'],datetime.strptime("2006-09-12","%Y-%m-%d" ))
